@@ -339,8 +339,12 @@ while 1:
     # the session ends. 
     # if any joblog entry is for a job that ended less than a day ago, pass
     # remaining = start + walltime - NOW() + 86400
+    # walltime > TIME_TO_SEC(start) is because it's possible for walltime to be calculated from epoch
+    # job > 0 because the middleware makes entries with job=0, we don't want those, not real jobs
     job_arr = mysql(c, """SELECT 86400 + walltime - TIMESTAMPDIFF(SECOND, start, NOW()) AS remaining
       FROM joblog WHERE sessnum = "%s"
+      AND walltime < UNIX_TIMESTAMP(start)
+      AND job > 0
       AND 86400 + walltime - TIMESTAMPDIFF(SECOND, start, NOW()) > 0""" % sessnum)
     if job_arr:
       for row in job_arr:
